@@ -1,4 +1,4 @@
-//@line 42 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/feeds/src/FeedWriter.js"
+//@line 42 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/feeds/src/FeedWriter.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -7,6 +7,9 @@ const Cu = Components.utils;
 
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
 
+const FEEDWRITER_CID = Components.ID("{49bb6593-3aff-4eb3-a068-2712c28bd58e}");
+const FEEDWRITER_CONTRACTID = "@mozilla.org/browser/feeds/result-writer;1";
+
 function LOG(str) {
   var prefB = Cc["@mozilla.org/preferences-service;1"].
               getService(Ci.nsIPrefBranch);
@@ -213,7 +216,8 @@ FeedWriter.prototype = {
   __contentSandbox: null,
   get _contentSandbox() {
     if (!this.__contentSandbox)
-      this.__contentSandbox = new Cu.Sandbox(this._window);
+      this.__contentSandbox = new Cu.Sandbox(this._window, 
+                                             {sandboxName: 'FeedWriter'});
 
     return this.__contentSandbox;
   },
@@ -641,7 +645,7 @@ FeedWriter.prototype = {
    * @returns The display name of the application represented by the file.
    */
   _getFileDisplayName: function FW__getFileDisplayName(file) {
-//@line 698 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/feeds/src/FeedWriter.js"
+//@line 702 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/feeds/src/FeedWriter.js"
     return file.leafName;
   },
 
@@ -704,9 +708,9 @@ FeedWriter.prototype = {
           // XXXben - we need to compare this with the running instance executable
           //          just don't know how to do that via script...
           // XXXmano TBD: can probably add this to nsIShellService
-//@line 766 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/feeds/src/FeedWriter.js"
+//@line 770 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/feeds/src/FeedWriter.js"
           if (fp.file.leafName != "firefox-bin") {
-//@line 769 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/feeds/src/FeedWriter.js"
+//@line 773 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/feeds/src/FeedWriter.js"
             this._initMenuItemWithFile(this._contentSandbox.selectedAppMenuItem,
                                        this._selectedApp);
 
@@ -1318,17 +1322,12 @@ FeedWriter.prototype = {
       });
   },
 
-  // nsIClassInfo
-  getInterfaces: function FW_getInterfaces(countRef) {
-    var interfaces = [Ci.nsIFeedWriter, Ci.nsIClassInfo, Ci.nsISupports];
-    countRef.value = interfaces.length;
-    return interfaces;
-  },
-  getHelperForLanguage: function FW_getHelperForLanguage(language) null,
-  classID: Components.ID("{49bb6593-3aff-4eb3-a068-2712c28bd58e}"),
-  implementationLanguage: Ci.nsIProgrammingLanguage.JAVASCRIPT,
-  flags: Ci.nsIClassInfo.DOM_OBJECT,
-  QueryInterface: XPCOMUtils.generateQI([Ci.nsIFeedWriter, Ci.nsIClassInfo,
+  classID: FEEDWRITER_CID,
+  classInfo: XPCOMUtils.generateCI({classID: FEEDWRITER_CID,
+                                    contractID: FEEDWRITER_CONTRACTID,
+                                    interfaces: [Ci.nsIFeedWriter],
+                                    flags: Ci.nsIClassInfo.DOM_OBJECT}),
+  QueryInterface: XPCOMUtils.generateQI([Ci.nsIFeedWriter,
                                          Ci.nsIDOMEventListener, Ci.nsIObserver,
                                          Ci.nsINavHistoryObserver])
 };
