@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/feeds/src/WebContentConverter.js"
+//@line 39 "/usr/obj/firefox-9.0.1/mozilla-release/browser/components/feeds/src/WebContentConverter.js"
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
@@ -874,23 +874,14 @@ WebContentConverterRegistrar.prototype = {
     return this.QueryInterface(iid);
   },
 
-  /**
-   * See nsIClassInfo
-   */
-  getInterfaces: function WCCR_getInterfaces(countRef) {
-    var interfaces = 
-        [Ci.nsIWebContentConverterService, Ci.nsIWebContentHandlerRegistrar,
-         Ci.nsIObserver, Ci.nsIClassInfo, Ci.nsIFactory, Ci.nsISupports];
-    countRef.value = interfaces.length;
-    return interfaces;
-  },
-  getHelperForLanguage: function WCCR_getHelperForLanguage(language) {
-    return null;
-  },
   classID: WCCR_CLASSID,
-  implementationLanguage: Ci.nsIProgrammingLanguage.JAVASCRIPT,
-  flags: Ci.nsIClassInfo.DOM_OBJECT,
-  
+  classInfo: XPCOMUtils.generateCI({classID: WCCR_CLASSID,
+                                    contractID: WCCR_CONTRACTID,
+                                    interfaces: [Ci.nsIWebContentConverterService,
+                                                 Ci.nsIWebContentHandlerRegistrar,
+                                                 Ci.nsIObserver, Ci.nsIFactory],
+                                    flags: Ci.nsIClassInfo.DOM_OBJECT}),
+
   /**
    * See nsISupports
    */
@@ -898,9 +889,7 @@ WebContentConverterRegistrar.prototype = {
      [Ci.nsIWebContentConverterService, 
       Ci.nsIWebContentHandlerRegistrar,
       Ci.nsIObserver,
-      Ci.nsIClassInfo,
-      Ci.nsIFactory,
-      Ci.nsISupports]),
+      Ci.nsIFactory]),
 
   _xpcom_categories: [{
     category: "app-startup",
