@@ -24,6 +24,7 @@
  *   Asaf Romano <mano@mozilla.com>
  *   Ehsan Akhgari <ehsan.akhgari@gmail.com>
  *   Drew Willcoxon <adw@mozilla.com>
+ *   Steffen Wilberg <steffen.wilberg@web.de>
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -71,12 +72,12 @@ var PlacesOrganizer = {
     this._initFolderTree();
 
     var leftPaneSelection = "AllBookmarks"; // default to all-bookmarks
-    if ("arguments" in window && window.arguments.length > 0)
+    if (window.arguments && window.arguments[0])
       leftPaneSelection = window.arguments[0];
 
     this.selectLeftPaneQuery(leftPaneSelection);
     // clear the back-stack
-    this._backHistory.splice(0);
+    this._backHistory.splice(0, this._backHistory.length);
     document.getElementById("OrganizerCommand:Back").setAttribute("disabled", true);
 
     var view = this._content.treeBoxObject.view;
@@ -89,11 +90,13 @@ var PlacesOrganizer = {
     PlacesSearchBox.init();
 
     window.addEventListener("AppCommand", this, true);
-//@line 113 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/places/content/places.js"
+//@line 114 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/places/content/places.js"
 
     // remove the "Properties" context-menu item, we've our own details pane
     document.getElementById("placesContext")
             .removeChild(document.getElementById("placesContext_show:info"));
+
+    gPrivateBrowsingListener.init();
   },
 
   QueryInterface: function PO_QueryInterface(aIID) {
@@ -125,6 +128,7 @@ var PlacesOrganizer = {
   },
 
   destroy: function PO_destroy() {
+    gPrivateBrowsingListener.uninit();
   },
 
   _location: null,
@@ -138,7 +142,7 @@ var PlacesOrganizer = {
 
     if (this.location) {
       this._backHistory.unshift(this.location);
-      this._forwardHistory.splice(0);
+      this._forwardHistory.splice(0, this._forwardHistory.length);
     }
 
     this._location = aLocation;
@@ -253,17 +257,30 @@ var PlacesOrganizer = {
    *          the node to set up scope from
    */
   _setSearchScopeForNode: function PO__setScopeForNode(aNode) {
-    var itemId = aNode.itemId;
+    let itemId = aNode.itemId;
+
+    // Set default buttons status.
+    let bookmarksButton = document.getElementById("scopeBarAll");
+    bookmarksButton.hidden = false;
+    let downloadsButton = document.getElementById("scopeBarDownloads");
+    downloadsButton.hidden = true;
+
     if (PlacesUtils.nodeIsHistoryContainer(aNode) ||
         itemId == PlacesUIUtils.leftPaneQueries["History"]) {
       PlacesQueryBuilder.setScope("history");
     }
-    // Default to All Bookmarks for all other nodes, per bug 469437.
-    else
+    else if (itemId == PlacesUIUtils.leftPaneQueries["Downloads"]) {
+      downloadsButton.hidden = false;
+      bookmarksButton.hidden = true;
+      PlacesQueryBuilder.setScope("downloads");
+    }
+    else {
+      // Default to All Bookmarks for all other nodes, per bug 469437.
       PlacesQueryBuilder.setScope("bookmarks");
+    }
 
     // Enable or disable the folder scope button.
-    var folderButton = document.getElementById("scopeBarFolder");
+    let folderButton = document.getElementById("scopeBarFolder");
     folderButton.hidden = !PlacesUtils.nodeIsFolder(aNode) ||
                           itemId == PlacesUIUtils.allBookmarksFolderId;
   },
@@ -344,19 +361,15 @@ var PlacesOrganizer = {
   },
 
   /**
-   * Show the migration wizard for importing from a file.
+   * Show the migration wizard for importing passwords,
+   * cookies, history, preferences, and bookmarks.
    */
-  importBookmarks: function PO_import() {
-    // XXX: ifdef it to be non-modal (non-"sheet") on mac (see bug 259039)
-    var features = "modal,centerscreen,chrome,resizable=no";
-
-    // The migrator window will set this to true when it closes, if the user
-    // chose to migrate from a specific file.
-    window.fromFile = false;
-    openDialog("chrome://browser/content/migration/migration.xul",
-               "migration", features, "bookmarks");
-    if (window.fromFile)
-      this.importFromFile();
+  importFromBrowser: function PO_importFromBrowser() {
+//@line 398 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/places/content/places.js"
+    let features = "modal,centerscreen,chrome,resizable=no";
+//@line 400 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/places/content/places.js"
+    window.openDialog("chrome://browser/content/migration/migration.xul",
+                      "migration", features);
   },
 
   /**
@@ -872,9 +885,21 @@ var PlacesSearchBox = {
         options.queryType = Ci.nsINavHistoryQueryOptions.QUERY_TYPE_HISTORY;
         content.load([query], options);
       }
-      else
+      else {
         content.applyFilter(filterString);
+      }
       break;
+    case "downloads": {
+        let query = PlacesUtils.history.getNewQuery();
+        query.searchTerms = filterString;
+        query.setTransitions([Ci.nsINavHistoryService.TRANSITION_DOWNLOAD], 1);
+        let options = currentOptions.clone();
+        // Make sure we're getting uri results.
+        options.resultType = currentOptions.RESULT_TYPE_URI;
+        options.queryType = Ci.nsINavHistoryQueryOptions.QUERY_TYPE_HISTORY;
+        content.load([query], options);
+      break;
+    }
     default:
       throw "Invalid filterCollection on search";
       break;
@@ -904,17 +929,28 @@ var PlacesSearchBox = {
 
   /**
    * Updates the display with the title of the current collection.
-   * @param   title
+   * @param   aTitle
    *          The title of the current collection.
    */
-  updateCollectionTitle: function PSB_updateCollectionTitle(title) {
-    if (title)
-      this.searchFilter.placeholder =
-        PlacesUIUtils.getFormattedString("searchCurrentDefault", [title]);
-    else
-      this.searchFilter.placeholder = this.filterCollection == "history" ?
-                                      PlacesUIUtils.getString("searchHistory") :
-                                      PlacesUIUtils.getString("searchBookmarks");
+  updateCollectionTitle: function PSB_updateCollectionTitle(aTitle) {
+    let title = "";
+    if (aTitle) {
+      title = PlacesUIUtils.getFormattedString("searchCurrentDefault",
+                                               [aTitle]);
+    }
+    else {
+      switch(this.filterCollection) {
+        case "history":
+          title = PlacesUIUtils.getString("searchHistory");
+          break;
+        case "downloads":
+          title = PlacesUIUtils.getString("searchDownloads");
+          break;
+        default:
+          title = PlacesUIUtils.getString("searchBookmarks");                                    
+      }
+    }
+    this.searchFilter.placeholder = title;
   },
 
   /**
@@ -996,6 +1032,9 @@ var PlacesQueryBuilder = {
     case "scopeBarFolder":
       this.setScope("collection");
       break;
+    case "scopeBarDownloads":
+      this.setScope("downloads");
+      break;
     case "scopeBarAll":
       this.setScope("bookmarks");
       break;
@@ -1011,7 +1050,8 @@ var PlacesQueryBuilder = {
    * PSB_search()).  If there is an active search, it's performed again to
    * update the content tree.
    * @param   aScope
-   *          the search scope, "bookmarks", "collection", or "history"
+   *          The search scope: "bookmarks", "collection", "downloads" or
+   *          "history".
    */
   setScope: function PQB_setScope(aScope) {
     // Determine filterCollection, folders, and scopeButtonId based on aScope.
@@ -1043,6 +1083,10 @@ var PlacesQueryBuilder = {
                    PlacesUtils.toolbarFolderId,
                    PlacesUtils.unfiledBookmarksFolderId);
       break;
+    case "downloads":
+      filterCollection = "downloads";
+      scopeButtonId = "scopeBarDownloads";
+      break;
     default:
       throw "Invalid search scope";
       break;
@@ -1320,4 +1364,41 @@ var ViewMenu = {
     result.sortingAnnotation = colLookupTable[columnId].anno || "";
     result.sortingMode = Ci.nsINavHistoryQueryOptions[sortConst];
   }
+}
+
+/**
+ * Disables the "Import and Backup->Import From Another Browser" menu item
+ * in private browsing mode.
+ */
+let gPrivateBrowsingListener = {
+  _cmd_import: null,
+
+  init: function PO_PB_init() {
+    this._cmd_import = document.getElementById("OrganizerCommand_browserImport");
+
+    let pbs = Cc["@mozilla.org/privatebrowsing;1"].
+              getService(Ci.nsIPrivateBrowsingService);
+    if (pbs.privateBrowsingEnabled)
+      this.updateUI(true);
+
+    Services.obs.addObserver(this, "private-browsing", false);
+  },
+
+  uninit: function PO_PB_uninit() {
+    Services.obs.removeObserver(this, "private-browsing");
+  },
+
+  observe: function PO_PB_observe(aSubject, aTopic, aData) {
+    if (aData == "enter")
+      this.updateUI(true);
+    else if (aData == "exit")
+      this.updateUI(false);
+  },
+
+  updateUI: function PO_PB_updateUI(PBmode) {
+    if (PBmode)
+      this._cmd_import.setAttribute("disabled", "true");
+    else
+      this._cmd_import.removeAttribute("disabled");
+  }
 };
