@@ -1,8 +1,7 @@
-//@line 39 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 39 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
-Components.utils.import("resource://gre/modules/Services.jsm");
 
 var gAdvancedPane = {
   _inited: false,
@@ -24,9 +23,9 @@ var gAdvancedPane = {
         advancedPrefs.selectedIndex = preference.value;
     }
 
-//@line 69 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 68 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
-//@line 73 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 72 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
     this.updateActualCacheSize();
   },
 
@@ -135,7 +134,7 @@ var gAdvancedPane = {
    */
   updateHardwareAcceleration: function()
   {
-//@line 185 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 185 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
   },
 
   // NETWORK TAB
@@ -444,7 +443,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-//@line 591 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 591 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -514,7 +513,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 661 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 661 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -560,5 +559,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 707 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/preferences/advanced.js"
+//@line 707 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/preferences/advanced.js"
 };
