@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/preferences/cookies.js"
+//@line 39 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/preferences/cookies.js"
 
 const nsICookie = Components.interfaces.nsICookie;
 
@@ -555,7 +555,7 @@ var gCookiesWindow = {
   },
 
   deleteCookie: function () {
-//@line 643 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/preferences/cookies.js"
+//@line 643 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/preferences/cookies.js"
     var seln = this._view.selection;
     var tbo = this._tree.treeBoxObject;
 
@@ -826,5 +826,10 @@ var gCookiesWindow = {
     var filter = document.getElementById("filter");
     filter.focus();
     filter.select();
+  },
+
+  onWindowKeyPress: function (aEvent) {
+    if (aEvent.keyCode == KeyEvent.DOM_VK_ESCAPE)
+      window.close();
   }
 };
