@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/i386/firefox-5.0/mozilla-release/browser/base/content/utilityOverlay.js"
+//@line 41 "/usr/obj/firefox-9.0.1/mozilla-release/browser/base/content/utilityOverlay.js"
 
 // Services = object with smart getters for common XPCOM services
 Components.utils.import("resource://gre/modules/Services.jsm");
@@ -94,9 +94,9 @@ function whereToOpenLink( e, ignoreButton, ignoreAlt )
 
   // Don't do anything special with right-mouse clicks.  They're probably clicks on context menu items.
 
-//@line 138 "/usr/obj/i386/firefox-5.0/mozilla-release/browser/base/content/utilityOverlay.js"
+//@line 139 "/usr/obj/firefox-9.0.1/mozilla-release/browser/base/content/utilityOverlay.js"
   if (ctrl || (middle && middleUsesTabs))
-//@line 140 "/usr/obj/i386/firefox-5.0/mozilla-release/browser/base/content/utilityOverlay.js"
+//@line 141 "/usr/obj/firefox-9.0.1/mozilla-release/browser/base/content/utilityOverlay.js"
     return shift ? "tabshifted" : "tab";
 
   if (alt)
@@ -378,9 +378,9 @@ function openAboutDialog() {
     return;
   }
 
-//@line 424 "/usr/obj/i386/firefox-5.0/mozilla-release/browser/base/content/utilityOverlay.js"
-  var features = "chrome,centerscreen,dependent";
-//@line 426 "/usr/obj/i386/firefox-5.0/mozilla-release/browser/base/content/utilityOverlay.js"
+//@line 427 "/usr/obj/firefox-9.0.1/mozilla-release/browser/base/content/utilityOverlay.js"
+  var features = "chrome,centerscreen,dependent,dialog=no";
+//@line 429 "/usr/obj/firefox-9.0.1/mozilla-release/browser/base/content/utilityOverlay.js"
   window.openDialog("chrome://browser/content/aboutDialog.xul", "", features);
 }
 
@@ -573,3 +573,12 @@ function openPrefsHelp() {
   var helpTopic = document.getElementsByTagName("prefwindow")[0].currentPane.helpTopic;
   openHelpLink(helpTopic, !instantApply);
 }
+
+function trimURL(aURL) {
+  // This function must not modify the given URL such that calling
+  // nsIURIFixup::createFixupURI with the result will produce a different URI.
+  return aURL /* remove single trailing slash for http/https/ftp URLs */
+             .replace(/^((?:http|https|ftp):\/\/[^/]+)\/$/, "$1")
+              /* remove http:// unless the host starts with "ftp\d*\." or contains "@" */
+             .replace(/^http:\/\/((?!ftp\d*\.)[^\/@]+(?:\/|$))/, "$1");
+}
