@@ -1,4 +1,3 @@
-pref("security.enable_ssl2",             false);
 pref("security.enable_ssl3",             true);
 pref("security.enable_tls",		 true);
 pref("security.enable_tls_session_tickets", true);
@@ -10,12 +9,6 @@ pref("security.ssl.require_safe_negotiation",  false);
 pref("security.ssl.warn_missing_rfc5746",  1);
 pref("security.ssl.enable_false_start", false);
 
-pref("security.ssl2.rc4_128", false);
-pref("security.ssl2.rc2_128", false);
-pref("security.ssl2.des_ede3_192", false);
-pref("security.ssl2.des_64", false);
-pref("security.ssl2.rc4_40", false);
-pref("security.ssl2.rc2_40", false);
 pref("security.ssl3.rsa_rc4_128_md5", true);
 pref("security.ssl3.rsa_rc4_128_sha", true);
 pref("security.ssl3.rsa_fips_des_ede3_sha", true);
@@ -26,15 +19,12 @@ pref("security.ssl3.rsa_1024_rc4_56_sha", false);
 pref("security.ssl3.rsa_1024_des_cbc_sha", false);
 pref("security.ssl3.rsa_rc4_40_md5", false);
 pref("security.ssl3.rsa_rc2_40_md5", false);
-// Camellia is broken on Windows CE for now, see bug 508113
-//@line 31 "/usr/obj/ports/firefox-5.0/mozilla-release/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_dss_camellia_256_sha", true);
 pref("security.ssl3.rsa_camellia_256_sha", true);
 pref("security.ssl3.dhe_rsa_camellia_128_sha", true);
 pref("security.ssl3.dhe_dss_camellia_128_sha", true);
 pref("security.ssl3.rsa_camellia_128_sha", true);
-//@line 38 "/usr/obj/ports/firefox-5.0/mozilla-release/netwerk/base/public/security-prefs.js"
 pref("security.ssl3.dhe_rsa_aes_256_sha", true);
 pref("security.ssl3.dhe_dss_aes_256_sha", true);
 pref("security.ssl3.rsa_aes_256_sha", true);
@@ -147,19 +137,23 @@ pref("browser.cache.disk.enable",           true);
 pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
-// Size explicitly set by the user. Used when smart_size.enabled == false
-//@line 69 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+// Size (in KB) explicitly set by the user. Used when smart_size.enabled == false
 pref("browser.cache.disk.capacity",         256000);
-//@line 73 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+// Max-size (in KB) for entries in disk cache. Set to -1 for no limit.
+// (Note: entries bigger than 1/8 of disk-cache are never cached)
+pref("browser.cache.disk.max_entry_size",    51200);  // 50 MB
 pref("browser.cache.memory.enable",         true);
-//pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
+//pref("browser.cache.memory.capacity",     -1);
+// Max-size (in KB) for entries in memory cache. Set to -1 for no limit.  
+// (Note: entries bigger than than 90% of the mem-cache are never cached)
+pref("browser.cache.memory.max_entry_size",  5120);
 pref("browser.cache.disk_cache_ssl",        true);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 82 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -170,21 +164,25 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 98 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
 
 // Whether or not indexedDB is enabled.
 pref("dom.indexedDB.enabled", true);
 // Space to allow indexedDB databases before prompting (in MB).
 pref("dom.indexedDB.warningQuota", 50);
 
+// Whether or not Web Workers are enabled.
+pref("dom.workers.enabled", true);
+// The number of workers per domain allowed to run concurrently.
+pref("dom.workers.maxPerDomain", 20);
+
+// Whether window.performance is enabled
+pref("dom.enable_performance", true);
+
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
 
-pref("browser.sessionhistory.optimize_eviction", false);
-
 pref("ui.use_native_colors", true);
-pref("ui.use_native_popup_windows", false);
 pref("ui.click_hold_context_menus", false);
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -245,13 +243,16 @@ pref("media.enforce_same_site_origin", false);
 // Media cache size in kilobytes
 pref("media.cache_size", 512000);
 
-//@line 176 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+// Master HTML5 media volume scale.
+pref("media.volume_scale", "1.0");
+
+//@line 180 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 179 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 183 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 182 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 186 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 184 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 188 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -261,28 +262,28 @@ pref("media.autoplay.enabled", true);
 pref("gfx.color_management.mode", 2);
 pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
+pref("gfx.color_management.enablev4", false);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
-//@line 200 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
-pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
-//@line 202 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 208 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 208 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 // use harfbuzz for default (0x01) + arabic (0x02)
 pref("gfx.font_rendering.harfbuzz.scripts", 3);
-//@line 211 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 211 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 218 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 216 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
+
+//@line 220 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 225 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 227 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -299,7 +300,7 @@ pref("accessibility.win32.force_disabled", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 245 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 247 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -335,6 +336,14 @@ pref("toolkit.scrollbox.smoothScroll", true);
 pref("toolkit.scrollbox.scrollIncrement", 20);
 pref("toolkit.scrollbox.clickToScroll.scrollDelay", 150);
 
+// Telemetry
+pref("toolkit.telemetry.enabled", false);
+pref("toolkit.telemetry.server", "https://data.mozilla.com");
+// Telemetry server owner. Please change if you set toolkit.telemetry.server to a different server
+pref("toolkit.telemetry.server_owner", "Mozilla");
+// Information page about telemetry (temporary ; will be about:telemetry in the end)
+pref("toolkit.telemetry.infoURL", "http://www.mozilla.com/legal/privacy/firefox.html#telemetry");
+
 // view source
 pref("view_source.syntax_highlight", true);
 pref("view_source.wrap_long_lines", false);
@@ -644,9 +653,9 @@ pref("dom.min_timeout_value", 4);
 pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 590 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 600 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 592 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 602 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -661,24 +670,27 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 609 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 619 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
 pref("javascript.options.methodjit.content", true);
-pref("javascript.options.methodjit.chrome",  false);
+pref("javascript.options.methodjit.chrome",  true);
 pref("javascript.options.jitprofiling.content", true);
-pref("javascript.options.jitprofiling.chrome",  false);
+pref("javascript.options.jitprofiling.chrome",  true);
+pref("javascript.options.pccounts.content", false);
+pref("javascript.options.pccounts.chrome",  false);
 pref("javascript.options.methodjit_always", false);
+pref("javascript.options.typeinference", true);
 // This preference limits the memory usage of javascript.
 // If you want to change these values for your device,
 // please find Bug 417052 comment 17 and Bug 456721
 // Comment 32 and Bug 613551.
 pref("javascript.options.mem.high_water_mark", 128);
 pref("javascript.options.mem.max", -1);
-pref("javascript.options.mem.gc_frequency",   300);
 pref("javascript.options.mem.gc_per_compartment", true);
 pref("javascript.options.mem.log", false);
+pref("javascript.options.gc_on_memory_pressure", true);
 
 // advanced prefs
 pref("advanced.mailftp",                    false);
@@ -707,7 +719,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 657 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 670 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -754,8 +766,14 @@ pref("network.http.proxy.keep-alive", true);
 // the packet is lost or delayed on the route.
 pref("network.http.keep-alive.timeout", 115);
 
-// limit the absolute number of http connections.
-pref("network.http.max-connections", 30);
+// Limit the absolute number of http connections.
+// Note: the socket transport service will clamp the number below 256 if the OS
+// cannot allocate that many FDs, and it also always tries to reserve up to 250
+// file descriptors for things other than sockets.   
+// -- windows using lower limit until bug 692260 resolved
+//@line 724 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
+pref("network.http.max-connections", 256);
+//@line 726 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // limit the absolute number of http connections that can be established per
 // host.  if a http proxy server is enabled, then the "server" is the proxy
@@ -814,6 +832,15 @@ pref("network.http.prompt-temp-redirect", true);
 // Section 4.8 "High-Throughput Data Service Class"
 pref("network.http.qos", 0);
 
+// The number of milliseconds after sending a SYN for an HTTP connection,
+// to wait before trying a different connection. 0 means do not use a second
+// connection.
+pref("network.http.connection-retry-timeout", 250);
+
+// Disable IPv6 for backup connections to workaround problems about broken
+// IPv6 connectivity.
+pref("network.http.fast-fallback-to-IPv4", false);
+
 // default values for FTP
 // in a DSCP environment this should be 40 (0x28, or AF11), per RFC-4594,
 // Section 4.8 "High-Throughput Data Service Class", and 80 (0x50, or AF22)
@@ -824,14 +851,53 @@ pref("network.ftp.control.qos", 0);
 // </http>
 
 // <ws>: WebSocket
-// The -76 websocket network protocol may be subject to HTTP cache poisoning
-// attacks. Until there is a secure open standard available and implemented
-// in necko the override-security-block preference must be set to true before
-// the normal enabled preference is considered. Bug 616733
-pref("network.websocket.override-security-block", false);
 pref("network.websocket.enabled", true);
+
+// mobile might want to set this much smaller
+pref("network.websocket.max-message-size", 16000000);
+
+// Should we automatically follow http 3xx redirects during handshake
+pref("network.websocket.auto-follow-http-redirects", false);
+
+// the number of seconds to wait for websocket connection to be opened
+pref("network.websocket.timeout.open", 20);
+
+// the number of seconds to wait for a clean close after sending the client
+// close message
+pref("network.websocket.timeout.close", 20);
+
+// the number of seconds of idle read activity to sustain before sending a
+// ping probe. 0 to disable.
+pref("network.websocket.timeout.ping.request", 0);
+
+// the deadline, expressed in seconds, for some read activity to occur after
+// generating a ping. If no activity happens then an error and unclean close
+// event is sent to the javascript websockets application
+pref("network.websocket.timeout.ping.response", 10);
+
+// Defines whether or not to try and negotiate the stream-deflate compression
+// extension with the websocket server. Stream-Deflate has been removed from
+// the standards track document, but can still be used by servers who opt
+// into it.
+pref("network.websocket.extensions.stream-deflate", false);
+
+// the maximum number of concurrent websocket sessions. By specification there
+// is never more than one handshake oustanding to an individual host at
+// one time.
+pref("network.websocket.max-connections", 200);
+
+// by default scripts loaded from a https:// origin can only open secure
+// (i.e. wss://) websockets.
+pref("network.websocket.allowInsecureFromHTTPS", false);
+
 // </ws>
 
+// Server-Sent Events
+
+pref("dom.server-events.enabled", true);
+// Equal to the DEFAULT_RECONNECTION_TIME_VALUE value in nsEventSource.cpp
+pref("dom.server-events.default-reconnection-time", 5000); // in milliseconds
+
 // If false, remote JAR files that are served with a content type other than
 // application/java-archive or application/x-jar will not be opened
 // by the jar channel.
@@ -876,6 +942,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -904,6 +971,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -913,11 +983,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -1003,7 +1076,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 958 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 1034 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1093,8 +1166,66 @@ pref("font.language.group",                 "chrome://global/locale/intl.propert
 pref("intl.uidirection.ar", "rtl");
 pref("intl.uidirection.he", "rtl");
 pref("intl.uidirection.fa", "rtl");
+pref("intl.uidirection.ur", "rtl");
 
-pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Standard Symbols L, DejaVu Sans, Cambria Math");
+// use en-US hyphenation by default for content tagged with plain lang="en"
+pref("intl.hyphenation-alias.en", "en-us");
+// and for other subtags of en-*, if no specific patterns are available
+pref("intl.hyphenation-alias.en-*", "en-us");
+
+pref("intl.hyphenation-alias.af-*", "af");
+pref("intl.hyphenation-alias.bg-*", "bg");
+pref("intl.hyphenation-alias.ca-*", "ca");
+pref("intl.hyphenation-alias.cy-*", "cy");
+pref("intl.hyphenation-alias.da-*", "da");
+pref("intl.hyphenation-alias.eo-*", "eo");
+pref("intl.hyphenation-alias.es-*", "es");
+pref("intl.hyphenation-alias.et-*", "et");
+pref("intl.hyphenation-alias.fi-*", "fi");
+pref("intl.hyphenation-alias.fr-*", "fr");
+pref("intl.hyphenation-alias.gl-*", "gl");
+pref("intl.hyphenation-alias.hr-*", "hr");
+pref("intl.hyphenation-alias.hsb-*", "hsb");
+pref("intl.hyphenation-alias.hu-*", "hu");
+pref("intl.hyphenation-alias.ia-*", "ia");
+pref("intl.hyphenation-alias.is-*", "is");
+pref("intl.hyphenation-alias.it-*", "it");
+pref("intl.hyphenation-alias.kmr-*", "kmr");
+pref("intl.hyphenation-alias.la-*", "la");
+pref("intl.hyphenation-alias.lt-*", "lt");
+pref("intl.hyphenation-alias.mn-*", "mn");
+pref("intl.hyphenation-alias.nl-*", "nl");
+pref("intl.hyphenation-alias.pt-*", "pt");
+pref("intl.hyphenation-alias.ru-*", "ru");
+pref("intl.hyphenation-alias.sl-*", "sl");
+pref("intl.hyphenation-alias.sv-*", "sv");
+pref("intl.hyphenation-alias.tr-*", "tr");
+pref("intl.hyphenation-alias.uk-*", "uk");
+
+// use reformed (1996) German patterns by default unless specifically tagged as de-1901
+// (these prefs may soon be obsoleted by better BCP47-based tag matching, but for now...)
+pref("intl.hyphenation-alias.de", "de-1996");
+pref("intl.hyphenation-alias.de-*", "de-1996");
+pref("intl.hyphenation-alias.de-DE-1901", "de-1901");
+pref("intl.hyphenation-alias.de-CH-*", "de-CH");
+
+// patterns from TeX are tagged as "sh" (Serbo-Croatian) macrolanguage;
+// alias "sr" (Serbian) and "bs" (Bosnian) to those patterns
+// (Croatian has its own separate patterns).
+pref("intl.hyphenation-alias.sr", "sh");
+pref("intl.hyphenation-alias.bs", "sh");
+pref("intl.hyphenation-alias.sh-*", "sh");
+pref("intl.hyphenation-alias.sr-*", "sh");
+pref("intl.hyphenation-alias.bs-*", "sh");
+
+// Norwegian has two forms, Bokmål and Nynorsk, with "no" as a macrolanguage encompassing both.
+// For "no", we'll alias to "nb" (Bokmål) as that is the more widely used written form.
+pref("intl.hyphenation-alias.no", "nb");
+pref("intl.hyphenation-alias.no-*", "nb");
+pref("intl.hyphenation-alias.nb-*", "nb");
+pref("intl.hyphenation-alias.nn-*", "nn");
+
+pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Asana Math, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
 // These fonts are ignored the underline offset, instead of it, the underline is lowered to bottom of its em descent.
@@ -1145,9 +1276,6 @@ pref("mousewheel.transaction.timeout", 1500);
 // mouse wheel scroll transaction is held even if the mouse cursor is moved.
 pref("mousewheel.transaction.ignoremovedelay", 100);
 
-// Macbook touchpad two finger pixel scrolling
-pref("mousewheel.enable_pixel_scrolling", true);
-
 // prefs for app level mouse wheel scrolling acceleration.
 // number of mousewheel clicks when acceleration starts
 // acceleration can be turned off if pref is set to -1
@@ -1258,12 +1386,6 @@ pref("bidi.numeral", 0);
 // 2 = OsBidisupport
 // 3 = disableBidisupport
 pref("bidi.support", 1);
-// ------------------
-//  Charset Mode
-// ------------------
-// 1 = doccharactersetBidi *
-// 2 = defaultcharactersetBidi
-pref("bidi.characterset", 1);
 // Whether delete and backspace should immediately delete characters not
 // visually adjacent to the caret, or adjust the visual position of the caret
 // on the first keypress and delete the character on a second keypress
@@ -1392,25 +1514,32 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1347 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 1472 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
+// How long a plugin process will wait for a response from the parent
+// to a synchronous request before terminating itself. After this
+// point the child assumes the parent is hung.
+// Disabled in release builds for Aurora and up
+pref("dom.ipc.plugins.parentTimeoutSecs", 0);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1358 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 1489 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1366 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 1497 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 // Linux plugins using Xt instead of Xembed don't work out-of-process yet.
 pref("dom.ipc.plugins.enabled.libvlcplugin.so", false);
 pref("dom.ipc.plugins.enabled.nppdf.so", false);
 pref("dom.ipc.plugins.enabled.602plugin.so", false);
-//@line 1373 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 1504 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
+
+pref("dom.ipc.processCount", 1);
 
 pref("svg.smil.enabled", true);
 
@@ -1447,15 +1576,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1833 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 2008 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 2261 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 2441 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 2461 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 2641 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 2730 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 2910 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 2734 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 2914 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.protocol-handler.warn-external.file", false);
 pref("browser.drag_out_of_frame_style", 1);
@@ -1723,11 +1852,11 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 3005 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 3185 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 3025 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 3205 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
-//@line 3033 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 3213 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1776,18 +1905,22 @@ pref("image.mem.discardable", true);
 
 // Prevents images from automatically being decoded on load, instead allowing
 // them to be decoded on demand when they are drawn.
-pref("image.mem.decodeondraw", false);
+pref("image.mem.decodeondraw", true);
 
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
 // value and twice this value.
-pref("image.mem.min_discard_timeout_ms", 120000);
+//
+// This used to be 120 seconds, but having it that high causes our working
+// set to grow very large. Switching it back to 10 seconds will hopefully
+// be better.
+pref("image.mem.min_discard_timeout_ms", 10000);
 
 // Chunk size for calls to the image decoders
-pref("image.mem.decode_bytes_at_a_time", 200000);
+pref("image.mem.decode_bytes_at_a_time", 4096);
 
 // The longest time we can spend in an iteration of an async decode
-pref("image.mem.max_ms_before_yield", 400);
+pref("image.mem.max_ms_before_yield", 5);
 
 // The maximum source data size for which we auto sync decode
 pref("image.mem.max_bytes_for_sync_decode", 150000);
@@ -1801,23 +1934,25 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3112 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
-
-//@line 3117 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+//@line 3294 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
+//@line 3299 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 pref("layers.acceleration.disabled", false);
+//@line 3301 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3136 "/usr/obj/ports/firefox-5.0/mozilla-release/modules/libpref/src/init/all.js"
+pref("layers.acceleration.draw-fps", false);
+
+//@line 3321 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
 
 // Enable/Disable the orientation API for content
-pref("accelerometer.enabled", true);
+pref("device.motion.enabled", true);
 
 // Enable/Disable HTML5 parser
 pref("html5.parser.enable", true);
@@ -1846,3 +1981,21 @@ pref("network.buffer.cache.size",  32768);
 
 // Desktop Notification
 pref("notification.feature.enabled", false);
+
+// Alert sliding effect
+pref("alerts.slideIncrement", 1);
+pref("alerts.slideIncrementTime", 10);
+pref("alerts.totalOpenTime", 4000);
+pref("alerts.disableSlidingEffect", false);
+
+// DOM full-screen API.
+pref("full-screen-api.enabled", false);
+pref("full-screen-api.allow-trusted-requests-only", true);
+pref("full-screen-api.key-input-restricted", true);
+
+// Time limit, in milliseconds, for nsEventStateManager::IsHandlingUserInput().
+// Used to detect long running handlers of user-generated events.
+pref("dom.event.handling-user-input-time-limit", 1000);
+ 
+//3D Transforms
+pref("layout.3d-transforms.enabled", false);
