@@ -1,4 +1,4 @@
-//@line 38 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 38 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 Components.utils.import("resource://gre/modules/Services.jsm");
@@ -26,7 +26,6 @@ const nsIURIFixup            = Components.interfaces.nsIURIFixup;
 const nsIWebNavigation       = Components.interfaces.nsIWebNavigation;
 const nsIWindowMediator      = Components.interfaces.nsIWindowMediator;
 const nsIWindowWatcher       = Components.interfaces.nsIWindowWatcher;
-const nsICategoryManager     = Components.interfaces.nsICategoryManager;
 const nsIWebNavigationInfo   = Components.interfaces.nsIWebNavigationInfo;
 const nsIBrowserSearchService = Components.interfaces.nsIBrowserSearchService;
 const nsICommandLineValidator = Components.interfaces.nsICommandLineValidator;
@@ -516,15 +515,15 @@ nsBrowserContentHandler.prototype = {
       cmdLine.preventDefault = true;
     }
 
-//@line 568 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 567 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser           Open a browser window.\n" +
              "  -new-window  <url> Open <url> in a new window.\n" +
              "  -new-tab     <url> Open <url> in a new tab.\n" +
-//@line 576 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 575 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
              "  -preferences       Open Preferences dialog.\n" +
-//@line 578 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 577 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
              "  -search     <term> Search <term> with your default search engine.\n",
 
   /* nsIBrowserHandler */
@@ -690,8 +689,6 @@ nsBrowserContentHandler.prototype = {
 };
 var gBrowserContentHandler = new nsBrowserContentHandler();
 
-const CONTRACTID_PREFIX = "@mozilla.org/uriloader/content-handler;1?type=";
-
 function handURIToExistingBrowser(uri, location, cmdLine)
 {
   if (!shouldLoadURI(uri))
@@ -735,13 +732,13 @@ nsDefaultCommandLineHandler.prototype = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 791 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 788 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 817 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/components/nsBrowserContentHandler.js"
+//@line 814 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
