@@ -1,4 +1,4 @@
-//@line 44 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 44 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
@@ -9,6 +9,7 @@ const XULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
 
 Cu.import("resource://gre/modules/XPCOMUtils.jsm");
 Cu.import("resource://gre/modules/Services.jsm");
+Cu.import("resource://gre/modules/AddonManager.jsm");
 
 XPCOMUtils.defineLazyGetter(this, "NetUtil", function() {
   Cu.import("resource://gre/modules/NetUtil.jsm");
@@ -20,7 +21,6 @@ XPCOMUtils.defineLazyGetter(this, "PlacesUtils", function() {
   return PlacesUtils;
 });
 
-const PREF_EM_NEW_ADDONS_LIST = "extensions.newAddons";
 const PREF_PLUGINS_NOTIFYUSER = "plugins.update.notifyUser";
 const PREF_PLUGINS_UPDATEURL  = "plugins.update.url";
 
@@ -65,7 +65,7 @@ function BrowserGlue() {
   this._init();
 }
 
-//@line 115 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 115 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
 
 BrowserGlue.prototype = {
   _saveSession: false,
@@ -87,7 +87,7 @@ BrowserGlue.prototype = {
     Services.prefs.savePrefFile(null);
   },
 
-//@line 137 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 137 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
   _setSyncAutoconnectDelay: function BG__setSyncAutoconnectDelay() {
     // Assume that a non-zero value for services.sync.autoconnectDelay should override
     if (Services.prefs.prefHasUserValue("services.sync.autoconnectDelay")) {
@@ -106,11 +106,10 @@ BrowserGlue.prototype = {
     }
     delay = delay <= MAX_DELAY ? delay : MAX_DELAY;
 
-    let syncTemp = {};
-    Cu.import("resource://services-sync/service.js", syncTemp);
-    syncTemp.Weave.Service.delayedAutoConnect(delay);
+    Cu.import("resource://services-sync/main.js");
+    Weave.SyncScheduler.delayedAutoConnect(delay);
   },
-//@line 160 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 159 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
 
   // nsIObserver implementation 
   observe: function BG_observe(subject, topic, data) {
@@ -144,7 +143,7 @@ BrowserGlue.prototype = {
         // on quit-application.
         this._setPrefToSaveSession();
         break;
-//@line 194 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 193 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
       case "browser-lastwindow-close-requested":
         // The application is not actually quitting, but the last full browser
         // window is about to be closed.
@@ -153,11 +152,11 @@ BrowserGlue.prototype = {
       case "browser-lastwindow-close-granted":
         this._setPrefToSaveSession();
         break;
-//@line 204 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 203 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
       case "weave:service:ready":
         this._setSyncAutoconnectDelay();
         break;
-//@line 208 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 207 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
       case "session-save":
         this._setPrefToSaveSession(true);
         subject.QueryInterface(Ci.nsISupportsPRBool);
@@ -214,6 +213,14 @@ BrowserGlue.prototype = {
         else if (data == "force-ui-migration") {
           this._migrateUI();
         }
+        else if (data == "force-distribution-customization") {
+          this._distributionCustomizer.applyPrefDefaults();
+          this._distributionCustomizer.applyCustomizations();
+          // To apply distribution bookmarks use "places-init-complete".
+        }
+        else if (data == "force-places-init") {
+          this._initPlaces();
+        }
         break;
     }
   }, 
@@ -229,12 +236,12 @@ BrowserGlue.prototype = {
     os.addObserver(this, "browser:purge-session-history", false);
     os.addObserver(this, "quit-application-requested", false);
     os.addObserver(this, "quit-application-granted", false);
-//@line 280 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 287 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.addObserver(this, "browser-lastwindow-close-requested", false);
     os.addObserver(this, "browser-lastwindow-close-granted", false);
-//@line 284 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 291 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.addObserver(this, "weave:service:ready", false);
-//@line 286 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 293 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.addObserver(this, "session-save", false);
     os.addObserver(this, "places-init-complete", false);
     this._isPlacesInitObserver = true;
@@ -255,12 +262,12 @@ BrowserGlue.prototype = {
     os.removeObserver(this, "browser:purge-session-history");
     os.removeObserver(this, "quit-application-requested");
     os.removeObserver(this, "quit-application-granted");
-//@line 307 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 314 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.removeObserver(this, "browser-lastwindow-close-requested");
     os.removeObserver(this, "browser-lastwindow-close-granted");
-//@line 311 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 318 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.removeObserver(this, "weave:service:ready", false);
-//@line 313 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 320 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     os.removeObserver(this, "session-save");
     if (this._isIdleObserver)
       this._idleService.removeIdleObserver(this, BOOKMARKS_BACKUP_IDLE_TIME);
@@ -294,30 +301,16 @@ BrowserGlue.prototype = {
     // handle any UI migration
     this._migrateUI();
 
-    // if ioService is managing the offline status, then ioservice.offline
-    // is already set correctly. We will continue to allow the ioService
-    // to manage its offline state until the user uses the "Work Offline" UI.
-    if (!Services.io.manageOfflineStatus) {
-      // set the initial state
-      try {
-        Services.io.offline = Services.prefs.getBoolPref("browser.offline");
-      }
-      catch (e) {
-        Services.io.offline = false;
-      }
-    }
-
     Services.obs.notifyObservers(null, "browser-ui-startup-complete", "");
   },
 
   // the first browser window has finished initializing
   _onFirstWindowLoaded: function BG__onFirstWindowLoaded() {
-//@line 376 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 368 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
   },
 
   // profile shutdown handler (contains profile cleanup routines)
   _onProfileShutdown: function BG__onProfileShutdown() {
-//@line 394 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
     this._shutdownPlaces();
     this._sanitizer.onShutdown();
   },
@@ -325,31 +318,16 @@ BrowserGlue.prototype = {
   // Browser startup complete. All initial windows have opened.
   _onBrowserStartup: function BG__onBrowserStartup() {
     // Show about:rights notification, if needed.
-    if (this._shouldShowRights())
+    if (this._shouldShowRights()) {
       this._showRightsNotification();
+//@line 386 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
+    }
+
 
     // Show update notification, if needed.
     if (Services.prefs.prefHasUserValue("app.update.postupdate"))
       this._showUpdateNotification();
 
-    // If new add-ons were installed during startup open the add-ons manager.
-    if (Services.prefs.prefHasUserValue(PREF_EM_NEW_ADDONS_LIST)) {
-      var args = Cc["@mozilla.org/supports-array;1"].
-                 createInstance(Ci.nsISupportsArray);
-      var str = Cc["@mozilla.org/supports-string;1"].
-                createInstance(Ci.nsISupportsString);
-      str.data = "";
-      args.AppendElement(str);
-      var str = Cc["@mozilla.org/supports-string;1"].
-                createInstance(Ci.nsISupportsString);
-      str.data = Services.prefs.getCharPref(PREF_EM_NEW_ADDONS_LIST);
-      args.AppendElement(str);
-      const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
-      const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
-      Services.ww.openWindow(null, EMURL, "_blank", EMFEATURES, args);
-      Services.prefs.clearUserPref(PREF_EM_NEW_ADDONS_LIST);
-    }
-
     // Load the "more info" page for a locked places.sqlite
     // This property is set earlier by places-database-locked topic.
     if (this._isPlacesDatabaseLocked) {
@@ -360,6 +338,21 @@ BrowserGlue.prototype = {
     // been warned about them yet, open the plugins update page.
     if (Services.prefs.getBoolPref(PREF_PLUGINS_NOTIFYUSER))
       this._showPluginUpdatePage();
+
+    // For any add-ons that were installed disabled and can be enabled offer
+    // them to the user
+    var win = this.getMostRecentBrowserWindow();
+    var browser = win.gBrowser;
+    var changedIDs = AddonManager.getStartupChanges(AddonManager.STARTUP_CHANGE_INSTALLED);
+    AddonManager.getAddonsByIDs(changedIDs, function(aAddons) {
+      aAddons.forEach(function(aAddon) {
+        // If the add-on isn't user disabled or can't be enabled then skip it
+        if (!aAddon.userDisabled || !(aAddon.permissions & AddonManager.PERM_CAN_ENABLE))
+          return;
+
+        browser.selectedTab = browser.addTab("about:newaddon?id=" + aAddon.id);
+      })
+    });
   },
 
   _onQuitRequest: function BG__onQuitRequest(aCancelQuit, aQuitType) {
@@ -534,7 +527,7 @@ BrowserGlue.prototype = {
       return !Services.prefs.getBoolPref("browser.EULA.override");
     } catch (e) { }
 
-//@line 614 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 596 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
 
     // Look to see if the user has seen the current version or not.
     var currentVersion = Services.prefs.getIntPref("browser.rights.version");
@@ -581,8 +574,8 @@ BrowserGlue.prototype = {
     var currentVersion = Services.prefs.getIntPref("browser.rights.version");
     Services.prefs.setBoolPref("browser.rights." + currentVersion + ".shown", true);
 
-    var box = notifyBox.appendNotification(notifyRightsText, "about-rights", null, notifyBox.PRIORITY_INFO_LOW, buttons);
-    box.persistence = 3; // arbitrary number, just so bar sticks around for a bit
+    var notification = notifyBox.appendNotification(notifyRightsText, "about-rights", null, notifyBox.PRIORITY_INFO_LOW, buttons);
+    notification.persistence = -1; // Until user closes it
   },
 
   _showUpdateNotification: function BG__showUpdateNotification() {
@@ -651,10 +644,10 @@ BrowserGlue.prototype = {
                       }
                     ];
 
-      let box = notifyBox.appendNotification(text, "post-update-notification",
-                                             null, notifyBox.PRIORITY_INFO_LOW,
-                                             buttons);
-      box.persistence = 3;
+      let notification = notifyBox.appendNotification(text, "post-update-notification",
+                                                      null, notifyBox.PRIORITY_INFO_LOW,
+                                                      buttons);
+      notification.persistence = -1; // Until user closes it
     }
 
     if (actions.indexOf("showAlert") == -1)
@@ -699,6 +692,8 @@ BrowserGlue.prototype = {
     }
   },
 
+//@line 838 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
+
   _showPluginUpdatePage: function BG__showPluginUpdatePage() {
     Services.prefs.setBoolPref(PREF_PLUGINS_NOTIFYUSER, false);
 
@@ -956,10 +951,10 @@ BrowserGlue.prototype = {
                   ];
 
     var notifyBox = browser.getNotificationBox();
-    var box = notifyBox.appendNotification(text, title, null,
-                                           notifyBox.PRIORITY_CRITICAL_MEDIUM,
-                                           buttons);
-    box.persistence = -1; // Until user closes it
+    var notification = notifyBox.appendNotification(text, title, null,
+                                                    notifyBox.PRIORITY_CRITICAL_MEDIUM,
+                                                    buttons);
+    notification.persistence = -1; // Until user closes it
   },
 
   _migrateUI: function BG__migrateUI() {
@@ -1288,7 +1283,7 @@ BrowserGlue.prototype = {
     }
   },
 
-//@line 1370 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 1431 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
 
   // this returns the most recent non-popup browser window
   getMostRecentBrowserWindow: function BG_getMostRecentBrowserWindow() {
@@ -1297,7 +1292,7 @@ BrowserGlue.prototype = {
              !win.document.documentElement.getAttribute("chromehidden");
     }
 
-//@line 1379 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 1440 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
     var win = Services.wm.getMostRecentWindow("navigator:browser");
 
     // if we're lucky, this isn't a popup, and we can just return this
@@ -1312,7 +1307,7 @@ BrowserGlue.prototype = {
       }
     }
     return win;
-//@line 1402 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/nsBrowserGlue.js"
+//@line 1463 "/usr/obj/ports/firefox-9.0.1/mozilla-release/browser/components/nsBrowserGlue.js"
   },
 
 
