@@ -1,8 +1,8 @@
-//@line 38 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
+//@line 38 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
 
 Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");
 
-//@line 44 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
+//@line 44 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
 
 ////////////////////////////////////////////////////////////////////////////////
 //// Utilities
@@ -301,7 +301,7 @@ PrivateBrowsingService.prototype = {
     if (!win.closed)
       return win;
 
-//@line 343 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
+//@line 343 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
     win = null;
     var windowsEnum = wm.getEnumerator("navigator:browser");
     // this is oldest to newest, so this gets a bit ugly
@@ -311,7 +311,7 @@ PrivateBrowsingService.prototype = {
         win = nextWin;
     }
     return win;
-//@line 361 "/usr/obj/ports/firefox-5.0/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
+//@line 361 "/usr/ports/pobj/firefox-9.0.1/mozilla-release/browser/components/privatebrowsing/src/nsPrivateBrowsingService.js"
   },
 
   _ensureCanCloseWindows: function PBS__ensureCanCloseWindows() {
@@ -457,41 +457,43 @@ PrivateBrowsingService.prototype = {
     if (this._currentStatus != STATE_IDLE)
       throw Cr.NS_ERROR_FAILURE;
 
+    if (val == this._inPrivateBrowsing)
+      return;
+
     try {
+      if (val) {
+        if (!this._canEnterPrivateBrowsingMode())
+          return;
+      }
+      else {
+        if (!this._canLeavePrivateBrowsingMode())
+          return;
+      }
+
+      this._ensureCanCloseWindows();
+
+      // start the transition now that we know that we can
       this._currentStatus = STATE_TRANSITION_STARTED;
 
-      if (val != this._inPrivateBrowsing) {
-        if (val) {
-          if (!this._canEnterPrivateBrowsingMode())
-            return;
-        }
-        else {
-          if (!this._canLeavePrivateBrowsingMode())
-            return;
-        }
+      this._autoStarted = this._prefs.getBoolPref("browser.privatebrowsing.autostart");
+      this._inPrivateBrowsing = val != false;
 
-        this._ensureCanCloseWindows();
+      let data = val ? "enter" : "exit";
 
-        this._autoStarted = this._prefs.getBoolPref("browser.privatebrowsing.autostart");
-        this._inPrivateBrowsing = val != false;
+      let quitting = Cc["@mozilla.org/supports-PRBool;1"].
+                     createInstance(Ci.nsISupportsPRBool);
+      quitting.data = this._quitting;
 
-        let data = val ? "enter" : "exit";
+      // notify observers of the pending private browsing mode change
+      this._obs.notifyObservers(quitting, "private-browsing-change-granted", data);
 
-        let quitting = Cc["@mozilla.org/supports-PRBool;1"].
-                       createInstance(Ci.nsISupportsPRBool);
-        quitting.data = this._quitting;
+      // destroy the current session and start initial cleanup
+      this._onBeforePrivateBrowsingModeChange();
 
-        // notify observers of the pending private browsing mode change
-        this._obs.notifyObservers(quitting, "private-browsing-change-granted", data);
+      this._obs.notifyObservers(quitting, "private-browsing", data);
 
-        // destroy the current session and start initial cleanup
-        this._onBeforePrivateBrowsingModeChange();
-
-        this._obs.notifyObservers(quitting, "private-browsing", data);
-
-        // load the appropriate session
-        this._onAfterPrivateBrowsingModeChange();
-      }
+      // load the appropriate session
+      this._onAfterPrivateBrowsingModeChange();
     } catch (ex) {
       // We aborted the transition to/from private browsing, we must restore the
       // beforeunload handling on all the windows for which we switched it off.
@@ -571,11 +573,9 @@ PrivateBrowsingService.prototype = {
     }
 
     // Plugin data
-    let (ph = Cc["@mozilla.org/plugin/host;1"].getService(Ci.nsIPluginHost)) {
-      const phInterface = Ci.nsIPluginHost;
-      const FLAG_CLEAR_ALL = phInterface.FLAG_CLEAR_ALL;
-      ph.QueryInterface(phInterface);
-
+    const phInterface = Ci.nsIPluginHost;
+    const FLAG_CLEAR_ALL = phInterface.FLAG_CLEAR_ALL;
+    let (ph = Cc["@mozilla.org/plugin/host;1"].getService(phInterface)) {
       let tags = ph.getPluginTags();
       for (let i = 0; i < tags.length; i++) {
         try {
