@@ -1,12 +1,12 @@
-//@line 37 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 37 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 // XXX Toolkit-specific preferences should be moved into toolkit.js
 
-//@line 41 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 41 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
-//@line 44 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 44 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
-//@line 50 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 50 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 pref("browser.chromeURL","chrome://browser/content/");
 pref("browser.hiddenWindowChromeURL", "chrome://browser/content/hiddenWindow.xul");
@@ -17,10 +17,10 @@ pref("extensions.logging.enabled", false);
 // Preferences for AMO integration
 pref("extensions.getAddons.cache.enabled", true);
 pref("extensions.getAddons.maxResults", 15);
-pref("extensions.getAddons.get.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/guid:%IDS%?src=firefox&appOS=%OS%&appVersion=%VERSION%&tMain=%TIME_MAIN%&tFirstPaint=%TIME_FIRST_PAINT%&tSessionRestored=%TIME_SESSION_RESTORED%");
-pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/%APP%/search?q=%TERMS%");
-pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/%APP%/api/%API_VERSION%/search/%TERMS%/all/%MAX_RESULTS%/%OS%/%VERSION%?src=firefox");
-pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%LOCALE%/%APP%/discovery/pane/%VERSION%/%OS%");
+pref("extensions.getAddons.get.url", "https://services.addons.mozilla.org/%LOCALE%/firefox/api/%API_VERSION%/search/guid:%IDS%?src=firefox&appOS=%OS%&appVersion=%VERSION%&tMain=%TIME_MAIN%&tFirstPaint=%TIME_FIRST_PAINT%&tSessionRestored=%TIME_SESSION_RESTORED%");
+pref("extensions.getAddons.search.browseURL", "https://addons.mozilla.org/%LOCALE%/firefox/search?q=%TERMS%");
+pref("extensions.getAddons.search.url", "https://services.addons.mozilla.org/%LOCALE%/firefox/api/%API_VERSION%/search/%TERMS%/all/%MAX_RESULTS%/%OS%/%VERSION%?src=firefox");
+pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%LOCALE%/firefox/discovery/pane/%VERSION%/%OS%");
 
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
@@ -30,16 +30,21 @@ pref("extensions.blocklist.interval", 86400);
 pref("extensions.blocklist.level", 2);
 pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
 pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.itemURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
 
 pref("extensions.update.autoUpdateDefault", true);
 
-// Dictionary download preference
-pref("browser.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/%APP%/dictionaries/");
+// Disable add-ons installed into the shared user and shared system areas by
+// default. This does not include the application directory. See the SCOPE
+// constants in AddonManager.jsm for values to use here
+pref("extensions.autoDisableScopes", 15);
 
-// Update Timer Manager preferences
-// Interval: When all registered timers should be checked (in milliseconds)
-//           default=10 minutes
-pref("app.update.timer", 600000);
+// Dictionary download preference
+pref("browser.dictionaries.download.url", "https://addons.mozilla.org/%LOCALE%/firefox/dictionaries/");
+
+// The minimum delay in seconds for the timer to fire.
+// default=2 minutes
+pref("app.update.timerMinimumDelay", 120);
 
 // App-specific update preferences
 
@@ -125,13 +130,8 @@ pref("app.update.url", "https://aus3.mozilla.org/update/3/%PRODUCT%/%VERSION%/%B
 //pref("app.update.url.override", "");
 
 // app.update.interval is in branding section
+// app.update.promptWaitTime is in branding section
 
-// Interval: Time before prompting the user again to restart to install the
-//           latest download (in seconds) default=1 day
-pref("app.update.nagTimer.restart", 86400);
-
-// Give the user x seconds to react before showing the big UI. default=12 hours
-pref("app.update.promptWaitTime", 43200);
 // Show the Update Checking/Ready UI when the user was idle for x seconds
 pref("app.update.idletime", 60);
 
@@ -160,7 +160,7 @@ pref("extensions.update.url", "https://versioncheck.addons.mozilla.org/update/Ve
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every day
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
-pref("extensions.getMoreThemesURL", "https://addons.mozilla.org/%LOCALE%/%APP%/getpersonas");
+pref("extensions.getMoreThemesURL", "https://addons.mozilla.org/%LOCALE%/firefox/getpersonas");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
@@ -182,9 +182,9 @@ pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
 
 pref("general.smoothScroll", false);
-//@line 226 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 226 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("general.autoScroll", false);
-//@line 230 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 230 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 // Whether or not the application should check at startup each time if it 
 // is the default browser.
@@ -211,13 +211,13 @@ pref("browser.warnOnRestart", false);
 pref("browser.showQuitWarning", false);
 pref("browser.fullscreen.autohide", true);
 pref("browser.fullscreen.animateUp", 1);
-pref("browser.overlink-delay", 70);
+pref("browser.overlink-delay", 80);
 
-//@line 259 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 259 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 264 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 264 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.urlbar.doubleClickSelectsAll", true);
-//@line 268 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 268 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.urlbar.autoFill", false);
 // 0: Match anywhere (e.g., middle of words)
 // 1: Match on word boundaries and then try matching anywhere
@@ -253,17 +253,18 @@ pref("browser.urlbar.match.url", "@");
 // 2 = only bookmarks, 3 = visited bookmarks, 1+16 = history matching in the url
 pref("browser.urlbar.default.behavior", 0);
 
+pref("browser.urlbar.formatting.enabled", true);
+pref("browser.urlbar.trimURLs", true);
+
 // Number of milliseconds to wait for the http headers (and thus
 // the Content-Disposition filename) before giving up and falling back to 
 // picking a filename without that info in hand so that the user sees some
 // feedback from their action.
-pref("browser.download.saveLinkAsFilenameTimeout", 1000);
+pref("browser.download.saveLinkAsFilenameTimeout", 4000);
 
 pref("browser.download.useDownloadDir", true);
 
-//@line 315 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.download.folderList", 1);
-//@line 317 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.download.manager.showAlertOnComplete", true);
 pref("browser.download.manager.showAlertInterval", 2000);
 pref("browser.download.manager.retention", 2);
@@ -277,7 +278,7 @@ pref("browser.download.manager.scanWhenDone", true);
 pref("browser.download.manager.resumeOnWakeDelay", 10000);
 
 // search engines URL
-pref("browser.search.searchEnginesURL",      "https://addons.mozilla.org/%LOCALE%/%APP%/search-engines/");
+pref("browser.search.searchEnginesURL",      "https://addons.mozilla.org/%LOCALE%/firefox/search-engines/");
 
 // pointer to the default engine name
 pref("browser.search.defaultenginename",      "chrome://browser-region/locale/region.properties");
@@ -302,10 +303,6 @@ pref("browser.search.update.log", false);
 // Check whether we need to perform engine updates every 6 hours
 pref("browser.search.update.interval", 21600);
 
-// Whether or not microsummary and generator updates are enabled
-pref("browser.microsummary.enabled", true);
-pref("browser.microsummary.updateGenerators", true);
-
 // enable search suggestions by default
 pref("browser.search.suggest.enabled", true);
 
@@ -321,9 +318,7 @@ pref("browser.link.open_newwindow", 3);
 pref("browser.link.open_newwindow.restriction", 2);
 
 // Tabbed browser
-//@line 375 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.tabs.autoHide", false);
-//@line 379 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.tabs.closeWindowWithLastTab", true);
 pref("browser.tabs.insertRelatedAfterCurrent", true);
 pref("browser.tabs.warnOnClose", true);
@@ -369,9 +364,7 @@ pref("browser.bookmarks.max_backups",             10);
 // Scripts & Windows prefs
 pref("dom.disable_open_during_load",              true);
 pref("javascript.options.showInConsole",          true);
-//@line 427 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
-
-//@line 432 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 417 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 // This is the pref to control the location bar, change this to true to 
 // force this - this makes the origin of popup windows more obvious to avoid
@@ -431,10 +424,10 @@ pref("browser.gesture.swipe.left", "Browser:BackOrBackDuplicate");
 pref("browser.gesture.swipe.right", "Browser:ForwardOrForwardDuplicate");
 pref("browser.gesture.swipe.up", "cmd_scrollTop");
 pref("browser.gesture.swipe.down", "cmd_scrollBottom");
-//@line 495 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 480 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.latched", false);
 pref("browser.gesture.pinch.threshold", 25);
-//@line 498 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 483 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.gesture.pinch.out", "");
 pref("browser.gesture.pinch.in", "");
 pref("browser.gesture.pinch.out.shift", "");
@@ -446,7 +439,7 @@ pref("browser.gesture.twist.left", "");
 pref("browser.gesture.tap", "cmd_fullZoomReset");
 
 // 0=lines, 1=pages, 2=history , 3=text size
-//@line 523 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 508 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("mousewheel.withshiftkey.action",2);
 pref("mousewheel.withshiftkey.sysnumlines",false);
 pref("mousewheel.withshiftkey.numlines",1);
@@ -456,7 +449,7 @@ pref("mousewheel.withaltkey.numlines",1);
 pref("mousewheel.withmetakey.action",0);
 pref("mousewheel.withmetakey.sysnumlines",true);
 pref("mousewheel.withmetakey.numlines",1);
-//@line 533 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 518 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("mousewheel.withcontrolkey.action",3);
 pref("mousewheel.withcontrolkey.sysnumlines",false);
 pref("mousewheel.withcontrolkey.numlines",1);
@@ -512,16 +505,16 @@ pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
 pref("plugins.hide_infobar_for_missing_plugin", true);
 pref("plugins.hide_infobar_for_outdated_plugin", false);
 
-//@line 591 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 577 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
 pref("plugins.update.notifyUser", false);
 
-//@line 598 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 584 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.preferences.instantApply", true);
-//@line 603 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 589 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 605 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 591 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -530,9 +523,9 @@ pref("browser.download.hide_plugins_without_extensions", true);
 // 0 goes Back/Forward
 // 1 act like PgUp/PgDown
 // 2 and other values, nothing
-//@line 614 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 600 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.backspace_action", 2);
-//@line 618 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 604 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 // this will automatically enable inline spellchecking (if it is available) for
 // editable elements in HTML
@@ -621,7 +614,7 @@ pref("gecko.handlerService.schemes.ircs.3.uriTemplate", "chrome://browser-region
 // By default, we don't want protocol/content handlers to be registered from a different host, see bug 402287
 pref("gecko.handlerService.allowRegisterFromDifferentHost", false);
 
-//@line 707 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 693 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 // Safe browsing does nothing unless this pref is set
 pref("browser.safebrowsing.enabled", false);
 
@@ -647,8 +640,8 @@ pref("browser.safebrowsing.provider.0.reportMalwareURL", "http://{moz:locale}.ma
 pref("browser.safebrowsing.provider.0.reportMalwareErrorURL", "http://{moz:locale}.malware-error.mozilla.com/?hl={moz:locale}");
 
 // FAQ URLs
-pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/phishing-protection/");
-pref("browser.geolocation.warning.infoURL", "http://www.mozilla.com/%LOCALE%/%APP%/geolocation/");
+pref("browser.safebrowsing.warning.infoURL", "http://www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+pref("browser.geolocation.warning.infoURL", "http://www.mozilla.com/%LOCALE%/firefox/geolocation/");
 
 // Name of the about: page contributed by safebrowsing to handle display of error
 // pages on phishing/malware hits.  (bug 399233)
@@ -665,17 +658,16 @@ pref("urlclassifier.gethashtables", "goog-phish-shavar,goog-malware-shavar");
 // the database.
 pref("urlclassifier.confirm-age", 2700);
 
-//@line 756 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
-
 // Maximum size of the sqlite3 cache during an update, in bytes
-//@line 759 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
-pref("urlclassifier.updatecachemax", 104857600);
-//@line 763 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+pref("urlclassifier.updatecachemax", 41943040);
+
+// Maximum size of the sqlite3 cache for lookups, in bytes
+pref("urlclassifier.lookupcachemax", 1048576);
 
 // URL for checking the reason for a malware warning.
 pref("browser.safebrowsing.malware.reportURL", "http://safebrowsing.clients.google.com/safebrowsing/diagnostic?client=%NAME%&hl=%LOCALE%&site=");
 
-//@line 768 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 746 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 pref("browser.EULA.version", 3);
 pref("browser.rights.version", 3);
@@ -684,9 +676,7 @@ pref("browser.rights.3.shown", false);
 // Don't show the about:rights notification
 pref("browser.rights.override", true);
 
-//@line 779 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_from_crash", true);
-//@line 781 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
 pref("browser.sessionstore.resume_session_once", false);
 
 // minimal interval between two save operations in milliseconds
@@ -707,12 +697,14 @@ pref("browser.sessionstore.max_windows_undo", 3);
 // number of crashes that can occur before the about:sessionrestore page is displayed
 // (this pref has no effect if more than 6 hours have passed since the last crash)
 pref("browser.sessionstore.max_resumed_crashes", 1);
-// The number of tabs that can restore concurrently:
-// < 0 = All tabs can restore at the same time
-//   0 = Only the selected tab in each window will be restored
-//       Other tabs won't be restored until they are selected
-//   N = The number of tabs to restore at the same time
-pref("browser.sessionstore.max_concurrent_tabs", 3);
+// restore_on_demand overrides MAX_CONCURRENT_TAB_RESTORES (sessionstore constant)
+// and restore_hidden_tabs. When true, tabs will not be restored until they are
+// focused (also applies to tabs that aren't visible). When false, the values
+// for MAX_CONCURRENT_TAB_RESTORES and restore_hidden_tabs are respected.
+// Selected tabs are always restored regardless of this pref.
+pref("browser.sessionstore.restore_on_demand", false);
+// Whether to automatically restore hidden tabs (i.e., tabs in other tab groups) or not
+pref("browser.sessionstore.restore_hidden_tabs", false);
 
 // allow META refresh by default
 pref("accessibility.blockautorefresh", false);
@@ -720,12 +712,6 @@ pref("accessibility.blockautorefresh", false);
 // Whether history is enabled or not.
 pref("places.history.enabled", true);
 
-// The percentage of system memory that the Places database can use.  Out of the
-// allowed cache size it will at most use the size of the database file.
-// Changes to this value are effective after an application restart.
-// Acceptable values are between 0 and 50.
-pref("places.database.cache_to_memory_percentage", 6);
-
 // the (maximum) number of the recent visits to sample
 // when calculating frecency
 pref("places.frecency.numVisits", 10);
@@ -787,7 +773,7 @@ pref("browser.zoom.updateBackgroundTabs", true);
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // base URL for web-based support pages
-pref("app.support.baseURL", "http://support.mozilla.com/1/%APP%/%VERSION%/%OS%/%LOCALE%/");
+pref("app.support.baseURL", "http://support.mozilla.com/1/firefox/%VERSION%/%OS%/%LOCALE%/");
 
 // Name of alternate about: page for certificate errors (when undefined, defaults to about:neterror)
 pref("security.alternate_certificate_error_page", "certerror");
@@ -802,26 +788,31 @@ pref("browser.privatebrowsing.dont_prompt_on_enter", false);
 // bookmarking dialog
 pref("browser.bookmarks.editDialog.firstEditField", "namePicker");
 
-// base url for the wifi geolocation network provider
-pref("geo.wifi.uri", "https://www.google.com/loc/json");
-pref("geo.wifi.protocol", 0);
-
-//@line 932 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
-
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 937 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 870 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("toolbar.customization.usesheet", false);
-//@line 939 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 872 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 950 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 884 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 pref("dom.ipc.plugins.enabled", true);
-//@line 952 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 886 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
-//@line 966 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 890 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
-//@line 968 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+// This pref governs whether we attempt to work around problems caused by
+// plugins using OS calls to manipulate the cursor while running out-of-
+// process.  These workarounds all involve intercepting (hooking) certain
+// OS calls in the plugin process, then arranging to make certain OS calls
+// in the browser process.  Eventually plugins will be required to use the
+// NPAPI to manipulate the cursor, and these workarounds will be removed.
+// See bug 621117.
+//@line 901 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
+
+//@line 913 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
+
+//@line 915 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 // The sync engines to use.
 pref("services.sync.registerEngines", "Bookmarks,Form,History,Password,Prefs,Tab");
 // Preferences to be synced by default
@@ -896,17 +887,58 @@ pref("services.sync.prefs.sync.security.warn_viewing_mixed", true);
 pref("services.sync.prefs.sync.signon.rememberSignons", true);
 pref("services.sync.prefs.sync.spellchecker.dictionary", true);
 pref("services.sync.prefs.sync.xpinstall.whitelist.required", true);
-//@line 1043 "/usr/ports/pobj/firefox-5.0/mozilla-release/browser/app/profile/firefox.js"
+//@line 990 "/usr/obj/firefox-9.0.1/mozilla-release/browser/app/profile/firefox.js"
 
-// Disable the error console and inspector
+// Disable the error console
 pref("devtools.errorconsole.enabled", false);
+
+// Enable the Inspector
 pref("devtools.inspector.enabled", false);
 
+// Enable the style inspector
+pref("devtools.styleinspector.enabled", false);
+
+// Enable the Scratchpad tool.
+pref("devtools.scratchpad.enabled", true);
+
+// Enable tools for Chrome development.
+pref("devtools.chrome.enabled", false);
+
 // The last Web Console height. This is initially 0 which means that the Web
 // Console will use the default height next time it shows.
 // Change to -1 if you do not want the Web Console to remember its last height.
 pref("devtools.hud.height", 0);
 
+// Remember the Web Console position. Possible values:
+//   above - above the web page,
+//   below - below the web page,
+//   window - in a separate window/popup panel.
+pref("devtools.webconsole.position", "above");
+
+// The number of lines that are displayed in the web console for the Net,
+// CSS, JS and Web Developer categories.
+pref("devtools.hud.loglimit.network", 200);
+pref("devtools.hud.loglimit.cssparser", 200);
+pref("devtools.hud.loglimit.exception", 200);
+pref("devtools.hud.loglimit.console", 200);
+
+// The developer tools editor configuration:
+// - tabsize: how many spaces to use when a Tab character is displayed.
+// - expandtab: expand Tab characters to spaces.
+pref("devtools.editor.tabsize", 4);
+pref("devtools.editor.expandtab", true);
+
+// Tells which component you want to use for source editing in developer tools.
+//
+// Available components:
+//   "textarea" - this is a basic text editor, like an HTML <textarea>.
+//
+//   "orion" - this is the Orion source code editor from the Eclipse project. It
+//   provides programmer-specific editor features such as syntax highlighting,
+//   indenting and bracket recognition. It may not be appropriate for all
+//   locales (esp. RTL) or a11y situations.
+pref("devtools.editor.component", "textarea");
+
 // Whether the character encoding menu is under the main Firefox button. This
 // preference is a string so that localizers can alter it.
 pref("browser.menu.showCharacterEncoding", "chrome://browser/locale/browser.properties");
