@@ -1,4 +1,6 @@
-//@line 37 "/usr/ports/pobj/firefox-5.0/mozilla-release/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/usr/obj/firefox-9.0.1/mozilla-release/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
